@@ -20,6 +20,7 @@ class Info(BaseModel):
     source          : Union[str, dict]
     date_created    : datetime
     destination     : Optional[dict]
+    meta            : Optional[dict]
     # fmt: on
 
 
@@ -95,16 +96,24 @@ class MultilayerImage_pydantic(BaseModel):
 
     def __hash__(self) -> int:
         warn("Multilayer_image.__hash__ is only well defined inside a YarrowDataset")
-        return hash((*set(self.image_id), self.name))
+        return hash((*sorted(self.image_id), self.name))
 
     def __eq__(self, other: Any) -> bool:
         warn("Multilayer_image.__eq__ is only well defined inside a YarrowDataset")
         if isinstance(other, MultilayerImage_pydantic):
             return all(
-                (set(self.image_id) == set(other.image_id), self.name == other.name)
+                (
+                    sorted(self.image_id) == sorted(other.image_id),
+                    self.name == other.name,
+                )
             )
         return NotImplemented
 
+    def __repr__(self):
+        return "MultilayerImage_pydantic(id={}, image_id={}, name={}, meta={})".format(
+            self.id, list(set(self.image_id)), self.name, self.meta
+        )
+
 
 class Clearance(BaseModel):
     # fmt: off
@@ -234,6 +243,7 @@ class Annotation_pydantic(BaseModel):
     is_crowd        : Optional[int] = Field(default=0, deprecated=True)
     mask            : Optional[RLE]
     polygon         : Optional[List[List[float]]]
+    polyline        : Optional[List[List[float]]]
     area            : Optional[float]
     bbox            : Optional[List[float]]
     keypoints       : Optional[List[List[float]]]
@@ -508,9 +518,33 @@ class YarrowDataset_pydantic(BaseModel):
     def _clean_unused(self):
         return NotImplemented
 
-    def save_to_file(self, fp):
+    def save_to_file(
+        self,
+        fp: str,
+        exclude_unset: bool = True,
+        indent: int = 4,
+        default=str,
+        **kwargs
+    ):
+        """Save this dataset to a file
+
+        :param fp: File path to save the dataset to
+        :type fp: _type_
+        :param exclude_unset: Exclude unset keys you should not write what you don't use, defaults to True
+        :type exclude_unset: bool, optional
+        :param indent: Number of indents in the json file, defaults to 4
+        :type indent: int, optional
+        :param default: default(obj) is a function that should return a serializable version of obj or raise TypeError. The default simply raises TypeError, defaults to str
+        :type default: obj, optional
+        """
         with open(fp, "w") as fp:
-            json.dump(self.dict(exclude_none=True), fp, default=str)
+            json.dump(
+                self.dict(exclude_unset=exclude_unset),
+                fp,
+                default=default,
+                indent=indent,
+                **kwargs
+            )
 
     def _check_valid_ids(self):
         results = []
